@@ -116,7 +116,7 @@ class ProbeChaos:
     def _probe(self):
 
         c__ = False
-        upper_lower_m = False
+        upper_lower_m = 0
 
         for c, i_ in zip(self._string, range(0, len(self._string))):
 
@@ -197,13 +197,13 @@ class ProbeChaos:
                     continue
 
                 if (is_lower and self.previous_printable_letter.isupper()) or (is_upper and self.previous_printable_letter.islower()):
-                    if not upper_lower_m:
-                        upper_lower_m = True
+                    if upper_lower_m < 2:
+                        upper_lower_m += 1
                     else:
                         self.successive_upper_lower += 1
-                        upper_lower_m = False
+                        upper_lower_m = 0
                 else:
-                    upper_lower_m = False
+                    upper_lower_m = 0
 
                 if is_latin:
                     self.previous_encountered_unicode_range = u_name
@@ -258,6 +258,6 @@ class ProbeChaos:
 
         bonus_sig_bom = -int(len(self._string)*0.5) if self._bonus_bom_sig is True else 0
 
-        initial_ratio = ((r_ + p_ + q_ + self.successive_upper_lower + self.successive_accent + self.successive_different_unicode_range + self.not_encountered_white_space + self.unprintable + z_ + bonus_sig_bom + ProbeChaos._unravel_cjk_suspicious_chinese.__func__(self._string, self.encountered_unicode_range_occurrences)) / len(self._string)) + self._probe_word.ratio  # + len(self.encountered_unicode_range)-1
+        initial_ratio = ((r_ + p_ + q_ + self.successive_upper_lower + self.successive_accent + self.successive_different_unicode_range + self.not_encountered_white_space + self.unprintable + z_ + bonus_sig_bom + ProbeChaos._unravel_cjk_suspicious_chinese.__func__(self._string, self.encountered_unicode_range_occurrences)) / len(self._string)) + self._probe_word.ratio
 
         return initial_ratio / 1.3 if self._bonus_multi_byte is True and initial_ratio > 0. else initial_ratio
